==> Receipts-1.7.0.zip: __MACOSX/Receipts.app/Contents/Resources/._repair-receipts-database.sh <==
    Mac OS X            	   2  %     &)                                      ATTR      &)     %	                       com.apple.cs.CodeDirectory          com.apple.cs.CodeRequirements            com.apple.cs.CodeRequirements-1    X  "  com.apple.cs.CodeSignature                  4        
             Mrepair-receipts-database 8SS3YPUJH9 $\W"Ϥ´_6ze2                    MDsXa                  H    ,            com.apple.bash                     repair-receipts-database                  
*Hcd                   
*Hcd
                
subject.OU        
8SS3YPUJH9                 4        
              Mrepair-receipts-database 8SS3YPUJH9 aυpC C>(,A                                {d:"9`4ϧU*ax0	*H
010
	`He 0	*H
  ?00z!0
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
120201221215Z
270201221215Z0y1-0+U$Developer ID Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0"0
	*H
  0
 vO[A#+_s?5
?$?O>mG	V)甝5
ʹ`)xEii`k_#:"1O4YBx.3E
EoZ[:2m6lp&D{HX#ş9~]2_R@꾬d[jDl>İ&{^j=GX1? v(mNi&NVtKfxLY 00UW|-,T0U00U#0+iGv	k.@GM^0.U'0%0#!http://crl.apple.com/root.crl0U0
*Hcd 0
	*H
  B9tkƤ7*
D,Ya2Կ;P9jDt[pKl#q-_œpe-xXI(3 zvOߨJVg/>ă:wmt.#Qo`H»ZFE~' "rorPu=%] 6H9;ꐀ.`x
S>O2VMxଚBzFXV,*EK4aUD'sNp000
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
060425214036Z
350209214036Z0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0"0
	*H
  0
 䑩	GP^y-6WLUKl"0>P	Af$kУ*zG[73Mir]_%UM]
d5#KYPXPg ˬ, op?0C=+I(ε^=: !.t<
bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U00U+iGv	k.@GM^0U#0+iGv	k.@GM^0U 00 	*Hcd00*+https://www.apple.com/appleca/0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0
	*H
  \6L-x팛wvw0O=G7@,ԱؾsdyO4آ>xk}9S 8ıO
k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
/Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!0t0\Ŧ$0
	*H
 0y1-0+U$Developer ID Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0
170608094130Z
220609094130Z010
	&,d
8SS3YPUJH91=0;U4Developer ID Application: Dirk Holtwick (8SS3YPUJH9)10U
8SS3YPUJH910U

Dirk Holtwick10	UUS0"0
	*H
  0
 YU6>`ng4R% !|d K%j:
seSͶԧVhD;Dځ4+pf.GF,{>BR#ujAM5K?7
_4QEӕ!:~X!AXEm5t$yeP^u.D"($wˏ".G9)+g 0C28*{
:_#ivΌbV 00>+2000.+0"http://ocsp.apple.com/ocsp-devid010Uy][D+[?9Ʈ0U0 0U#0W|-,T0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U0U%0
+0
*Hcd
 0
	*H
  (3.2\_|(;5,-FM^QU&i|wL$3$TSX^Xit}piveN_ dX؋nkK5<T ֈ
BL8A-Ǭ
yFp ;N3鉬]&k\lHUSA$@ MمKsE<!/KyCf5E~R'34l[iV86ޖcϛ12ó(*u1P0L00y1-0+U$Developer ID Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUSŦ$0
	`He 0	*H
	1	*H
0	*H
	1
180320105350Z0/	*H
	1" C؃JF	Z3*`?im0[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
<plist version="1.0">
<dict>
	<key>cdhashes</key>
	<array>
		<data>
		LL1Fhw2tKjjdOgLvPTrj2yV00cU=
		</data>
		<data>
		kniYPLpkV09RgrGGHzuJ3G/slvI=
		</data>
	</array>
</dict>
</plist>
0
	*H
  m=^cpؓ6m~VDj%$@ԥ>ny`#3B16@豕Ĥ>PJcs{ឿ0O-
zփWle!'">ɂ0`cE8
ȇݪx|ZWhUs%d~ kwU.r(*=a7a
ކGW*~ "97~c6SK
WebJ Wkܡ0*H
	10	*H
010	+ 0z*H
	ki0g*010
	`He  wY2Cbt"a$83KN9@9B<20180320105349Z0
HF	ߠ
00*['0
	*H
 0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0
180307235502Z
180418235502Z0A10UTimestamp Signer MA210U

Apple Inc.10	UUS0"0
	*H
  0
 =phY;:E~דfz|8qVGq_EsHeh	9lԋIo%i6"{y"?"@HkX9Wq
D_Η'PY#gT sl"9MG2 Pl;( 6>~(c6[ri(%u稁oɖC3b) 0Ř^82¢'T63{3;lTH|X
 00U\,"u?[@* ۽0U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.03U,0*0(&$"http://crl.apple.com/timestamp.crl0U0U%0
+0
	*H
  1*e#$l&5({zÛ8`a.-k!_yR6XA7
[ZHf4XCJV^&@	W
 vfM]OgeJYw÷s%ܗ΍U
PtTwBnFLȜZ|V}l _oy$r4
Z,+꾱nOfEgR9,-%I	Py00}LWc0
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
120405120244Z
270405120244Z0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0"0
	*H
  0
 wg\.#g>B	}
s@/P'4p
<No97ڞecIm] 9	:JidF5ea.
=o%L	x"!{[ѣ~I;
r3,JZr
9Pt(ny_~VVlĮ (tM&By^`EXQI^JMs{Rˣ]klt-D>a>E~4u&@u0Kw 00U4%N78X&)0U00U#0+iGv	k.@GM^0.U'0%0#!http://crl.apple.com/root.crl0U0
*Hcd	 0
	*H
  6qS#xe[#Ǣϴ(p!93rC=BQu]ˌjj:T}k>mzT_Cv\ N<>r4\ge0B4ӧBsu|QC`ܮ'kg3EoɘMiKEN"W""En?厸F\ɰ:m7(FeoUhR>?&:k22H;Kу000
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
060425214036Z
350209214036Z0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0"0
	*H
  0
 䑩	GP^y-6WLUKl"0>P	Af$kУ*zG[73Mir]_%UM]
d5#KYPXPg ˬ, op?0C=+I(ε^=: !.t<
bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U00U+iGv	k.@GM^0U#0+iGv	k.@GM^0U 00 	*Hcd00*+https://www.apple.com/appleca/0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0
	*H
  \6L-x팛wvw0O=G7@,ԱؾsdyO4آ>xk}9S 8ıO
k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
/Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!1?0;00|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS*['0	+ 0	*H
	1
*H
	0	*H
	1
180320105349Z0#	*H
	1\eVu[<ÕLbpY0+*H
	10008/R9˨1{0
	*H
  T3 1X4`va¤b9FTT~{Yܸ!n~^t 0CVb$NoS )xYrxr֏x~D;tE.«fn;>A-cc'~7&>5P9Tn!zD|mgTĝ80tIA~N@_%'/'X
	T%J[ʂ5ٻ_&c
ɻg8yٸnȇvd      

==> Receipts-1.7.1-176.zip: __MACOSX/Receipts.app/Contents/Resources/._repair-receipts-database.sh <==
    Mac OS X            	   2  %     &)                                      ATTR      &)     %	                       com.apple.cs.CodeDirectory          com.apple.cs.CodeRequirements            com.apple.cs.CodeRequirements-1    X  "  com.apple.cs.CodeSignature                  4        
             Mrepair-receipts-database 8SS3YPUJH9 $\W"Ϥ´_6ze2                    MDsXa                  H    ,            com.apple.bash                     repair-receipts-database                  
*Hcd                   
*Hcd
                
subject.OU        
8SS3YPUJH9                 4        
              Mrepair-receipts-database 8SS3YPUJH9 aυpC C>(,A                                {d:"9`4ϧU*ax0	*H
010
	`He 0	*H
  ?00z!0
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
120201221215Z
270201221215Z0y1-0+U$Developer ID Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0"0
	*H
  0
 vO[A#+_s?5
?$?O>mG	V)甝5
ʹ`)xEii`k_#:"1O4YBx.3E
EoZ[:2m6lp&D{HX#ş9~]2_R@꾬d[jDl>İ&{^j=GX1? v(mNi&NVtKfxLY 00UW|-,T0U00U#0+iGv	k.@GM^0.U'0%0#!http://crl.apple.com/root.crl0U0
*Hcd 0
	*H
  B9tkƤ7*
D,Ya2Կ;P9jDt[pKl#q-_œpe-xXI(3 zvOߨJVg/>ă:wmt.#Qo`H»ZFE~' "rorPu=%] 6H9;ꐀ.`x
S>O2VMxଚBzFXV,*EK4aUD'sNp000
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
060425214036Z
350209214036Z0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0"0
	*H
  0
 䑩	GP^y-6WLUKl"0>P	Af$kУ*zG[73Mir]_%UM]
d5#KYPXPg ˬ, op?0C=+I(ε^=: !.t<
bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U00U+iGv	k.@GM^0U#0+iGv	k.@GM^0U 00 	*Hcd00*+https://www.apple.com/appleca/0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0
	*H
  \6L-x팛wvw0O=G7@,ԱؾsdyO4آ>xk}9S 8ıO
k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
/Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!0t0\Ŧ$0
	*H
 0y1-0+U$Developer ID Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0
170608094130Z
220609094130Z010
	&,d
8SS3YPUJH91=0;U4Developer ID Application: Dirk Holtwick (8SS3YPUJH9)10U
8SS3YPUJH910U

Dirk Holtwick10	UUS0"0
	*H
  0
 YU6>`ng4R% !|d K%j:
seSͶԧVhD;Dځ4+pf.GF,{>BR#ujAM5K?7
_4QEӕ!:~X!AXEm5t$yeP^u.D"($wˏ".G9)+g 0C28*{
:_#ivΌbV 00>+2000.+0"http://ocsp.apple.com/ocsp-devid010Uy][D+[?9Ʈ0U0 0U#0W|-,T0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U0U%0
+0
*Hcd
 0
	*H
  (3.2\_|(;5,-FM^QU&i|wL$3$TSX^Xit}piveN_ dX؋nkK5<T ֈ
BL8A-Ǭ
yFp ;N3鉬]&k\lHUSA$@ MمKsE<!/KyCf5E~R'34l[iV86ޖcϛ12ó(*u1P0L00y1-0+U$Developer ID Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUSŦ$0
	`He 0	*H
	1	*H
0	*H
	1
180412154202Z0/	*H
	1" C؃JF	Z3*`?im0[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
<plist version="1.0">
<dict>
	<key>cdhashes</key>
	<array>
		<data>
		LL1Fhw2tKjjdOgLvPTrj2yV00cU=
		</data>
		<data>
		kniYPLpkV09RgrGGHzuJ3G/slvI=
		</data>
	</array>
</dict>
</plist>
0
	*H
  /mnaKy9ca
ݕӿ}.	ezY׈q"?SYPܜ@ؙX*VuhlŲTx'][h!g	A(nZh^ii~u[[XbtR2\t<D-s&K2ֺZ
>JzHxqq ~c	(=Clȅ5D#sӜ{d9'w.0*H
	10	*H
010	+ 0z*H
	ki0g*010
	`He  `vDiƌ@28Qh?&u
S-g(20180412154202Z0$=NN#ry
00Yc0
	*H
 0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0
180404235003Z
180516235003Z0A10UTimestamp Signer MA210U

Apple Inc.10	UUS0"0
	*H
  0
 %J5[RܔcEE0}pu`tvǙMLlsvT=h%frxR2qC!4orN#dlkQ ɻ+i=yy)3Zso/օ-JhAiIsC/8uTRˤH<5
ug3#+w+gS|?"6GJYD`YKyz.f(HYr 00U=B|.0#GjY0U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.03U,0*0(&$"http://crl.apple.com/timestamp.crl0U0U%0
+0
	*H
  OcU1~Tғ[#0:Ϡ$ot>WעZGխN{qXmHǝã7`b6Jq0!?Rc :de|pxƄeQF#N8X:61
Z߾?s!77\4"
,7AdX+4#WLr[u|kՀh;%ӂ5SN	
 iX\?p	[+p/00}LWc0
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
120405120244Z
270405120244Z0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0"0
	*H
  0
 wg\.#g>B	}
s@/P'4p
<No97ڞecIm] 9	:JidF5ea.
=o%L	x"!{[ѣ~I;
r3,JZr
9Pt(ny_~VVlĮ (tM&By^`EXQI^JMs{Rˣ]klt-D>a>E~4u&@u0Kw 00U4%N78X&)0U00U#0+iGv	k.@GM^0.U'0%0#!http://crl.apple.com/root.crl0U0
*Hcd	 0
	*H
  6qS#xe[#Ǣϴ(p!93rC=BQu]ˌjj:T}k>mzT_Cv\ N<>r4\ge0B4ӧBsu|QC`ܮ'kg3EoɘMiKEN"W""En?厸F\ɰ:m7(FeoUhR>?&:k22H;Kу000
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
060425214036Z
350209214036Z0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0"0
	*H
  0
 䑩	GP^y-6WLUKl"0>P	Af$kУ*zG[73Mir]_%UM]
d5#KYPXPg ˬ, op?0C=+I(ε^=: !.t<
bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U00U+iGv	k.@GM^0U#0+iGv	k.@GM^0U 00 	*Hcd00*+https://www.apple.com/appleca/0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0
	*H
  \6L-x팛wvw0O=G7@,ԱؾsdyO4آ>xk}9S 8ıO
k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
/Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!1?0;00|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUSYc0	+ 0	*H
	1
*H
	0	*H
	1
180412154202Z0#	*H
	1p@:iUp0+*H
	1000ȦoN"1ZG?F30
	*H
  /Ix&LxʽWҾl=@]O|oV̌OԨL$.ūCLujnvǌ.ob>2H2R0	ec(oJ?/zϺ7'4>tT҄P'U#J60/a%RyummkT][gGACOzYOӰ}]a\KUoU/|8Nf,#60B/1      
